package main

import (
	_ "embed"
	_ "github.com/mattn/go-sqlite3"
	"database/sql"
)

//go:embed init.sql
var initSQL string

type Db interface {
	// CheckAndStore checks if the tag is already stored in the database and stores it if it's not.
	CheckAndStore(repo, tag string) (bool, error)
}

type SQLiteDb struct {
	DB *sql.DB
}

func (s SQLiteDb) CheckAndStore(repo, tag string) (bool, error) {
	var count int
	err := s.DB.QueryRow("SELECT COUNT(*) FROM tags WHERE repo = ? AND tag = ?", repo, tag).Scan(&count)
	if err != nil {
		return false, err
	}
	if count > 0 {
		return false, nil
	}
	_, err = s.DB.Exec("INSERT INTO tags (repo, tag) VALUES (?, ?)", repo, tag)
	if err != nil {
		return false, err
	}
	return true, nil
}

// NewSQLiteDb creates a new SQLite database connection.
// The database is created if it doesn't exist.
func NewSQLiteDb(file string) (SQLiteDb, error) {
	db, err := sql.Open("sqlite3", file)
	if err != nil {
		return SQLiteDb{}, err
	}
	_, err = db.Exec(initSQL)
	if err != nil {
		return SQLiteDb{}, err
	}
	return SQLiteDb{DB: db}, nil
}
